---
Title: Open data formats
Author: Jutta
status: dump
---

# Open data formats

## Neutrino sets in the VO

Tabulated high-level neutrino event data can be provided through the VO
registry, utilizing access protocols like the Table Access Protocol
(TAP) and query languages like the Astronomical Data Query Language
(ADQL). To query these data sets related to astronomical sources, the
Simple Cone Search (SCS) protocol allows to pick specific events
according to particle source direction, using Unified Content
Descriptors (UCDs) to identify the relevant table columns. The
underlying data format is the VOTable which allows for metadata
annotation of data columns. As the DaCHS software provides input
capabilities for various formats like FITS\footnote{Flexible Image
  Transport System, \url{https://fits.gsfc.nasa.gov/}.} or text-based
tables on the server side, a common KM3NeT open event table format
can be chosen quite independently and the interface adapted such that high-level neutrino data
sets can be both offered through the VO and alternative access
protocols, as long as the required metadata description is handled
adequately.

VO standards are at the current stage not fully adapted
to the inclusion of neutrino data and require development of metadata
standards for easy interpretability of the data, a matter which is targeted within the ESCAPE project. Open questions in this regard are the linkage of observation probabilities to a given event selection, the inclusion of ``non-observation'' in a given field of view
and within a given time as relevant scientific information to retrieve
from the services, and the introduction of a dedicated vocabulary for the
description of neutrino data. This vocabulary will need to be developed within KM3NeT as a matter of internal standardization, however, the process will draw guidance from the VO expertise and framework.

## Multimessenger alerts

Single or stacked neutrino events of high astrophysical signal probability will be selected in KM3NeT to trigger an alert to other observatories indicating a
possible target for multimessenger observations \cite{MM}. The
VOEvent format, together with the VOEvent Transport
Protocol as implemented in the Comet
software\footnote{J. Swinbank, Comet, \url{https://comet.transientskp.org}.} will be used to distribute these events as outgoing alerts. As the format is specifically tailored to the use 
in multimessenger alerts, indicating a quite restricted scientific target, the providing of context information for the events can be specifically adapted to this use case. However, harmonization of metadata standards like parameter descriptors and event identifiers in reference to the full neutrino event sets will also have to be implemented.

## Providing simulation-driven services
Providing context information on a broader scale in the form of e.g. sensitivity services and instrument response functions alongside the VO-published data sets is still under investigation. On the one hand, VO access protocols like TAP facilitate the use of standardized queries on services. On the other hand, integrating those services with the data sets in a meaningful and user-transparent way, e.g. through VO Datalinks, still requires further deliberation. Therefore, the development of these services will be use-case driven and also include the application of similar services for studies in other fields of KM3NeT research beyond astrophysics.
